.. image:: https://raw.githubusercontent.com/cenkalti/kuyruk/master/docs/_static/lemur.png
   :alt: Kuyruk Logo

Kuyruk
======

.. image:: https://travis-ci.org/cenkalti/kuyruk.svg?branch=master
   :target: https://travis-ci.org/cenkalti/kuyruk?branch=master

.. image:: https://coveralls.io/repos/github/cenkalti/kuyruk/badge.svg?branch=master
   :target: https://coveralls.io/github/cenkalti/kuyruk?branch=master

.. image:: https://img.shields.io/pypi/v/kuyruk.svg?branch=master
   :target: https://pypi.org/project/Kuyruk/


Kuyruk is a simple and easy way of distributing tasks to run on servers.

It uses `RabbitMQ <http://www.rabbitmq.com>`_ as message broker and
depends on `amqp <http://amqp.readthedocs.org/>`_
which is a pure-Python RabbitMQ client library.
Compatible with Python 3.5+.


Where is the documentation?
---------------------------
Here it is: http://kuyruk.readthedocs.org
